#######################
Examples (``examples``)
#######################

.. automodule:: nimfa.examples
	:members:
	:undoc-members:
	:inherited-members:
	:show-inheritance:	


.. toctree::
   :maxdepth: 2
   
   nimfa.examples.synthetic
   
   nimfa.examples.all_aml
   
   nimfa.examples.medulloblastoma
   
   nimfa.examples.cbcl_images
   
   nimfa.examples.documents
   
   nimfa.examples.orl_images
   
   nimfa.examples.recommendations
   
   nimfa.examples.gene_func_prediction
